@@ -7,6 +7,10 @@
 #' 
 #' @param nodes Subset of nodes to examine the coverage of the network
 #' 
+#' @param weighted Is the network weighted?
+#' Defaults to FALSE.
+#' Set to TRUE for weighted measures
+#' 
 #' @return Returns a list containing:
 #' 
 #' \item{mean}{The average distance from the subset of nodes to all other nodes in the network}
@@ -22,12 +26,18 @@
 #' 
 #' result <- net.coverage(A, nodes)
 #' 
+#' @references 
+#' Christensen, A. P., Cotter, K. N., Silvia, P. J., & Benedek, M. (2018)
+#' Scale development via network analysis: A comprehensive and concise measure of Openness to Experience
+#' \emph{PsyArXiv}, 1-40.
+#' doi: \href{https://doi.org/10.31234/osf.io/3raxt}{10.31234/osf.io/3raxt}
+#' 
 #' @author Alexander Christensen <alexpaulchristensen@gmail.com>
 #' Mathias Benedek <mathias.benedek@uni-graz.at>
 #' 
 #' @export
 #Network Coverage----
-net.coverage <- function (A, nodes)
+net.coverage <- function (A, nodes, weighted = FALSE)
 {
     fnames <- colnames(A)
     
@@ -35,7 +45,7 @@ net.coverage <- function (A, nodes)
     {inames <- colnames(A)[nodes]
     }else{inames <- nodes}
     
-    dist <- distance(A)
+    dist <- distance(A, weighted = weighted)
     
     diag(dist) <- Inf
     
